#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#   Catfish - a versatile file searching tool
#   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
#
#   This program is free software: you can redistribute it and/or modify it
#   under the terms of the GNU General Public License version 2, as published
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranties of
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0413

"""Helpers for an Ubuntu application."""
import logging
import os
import sys

import gi
gi.require_version('GObject', '2.0')  # noqa
gi.require_version('Gtk', '3.0')  # noqa
from gi.repository import GObject, Gtk

from . catfishconfig import get_data_file
from . Builder import Builder

gobject_version = GObject.pygobject_version


def check_gobject_version(major_version, minor_version, micro=0):
    """Return true if running gobject >= requested version"""
    return gobject_version >= (major_version, minor_version, micro)


def xdg_current_desktop():
    desktop = os.environ.get("ORIGINAL_XDG_CURRENT_DESKTOP", None)
    if desktop is None:
        desktop = os.environ.get("XDG_CURRENT_DESKTOP", "")
    desktop = desktop.lower()
    if desktop == "ubuntu:gnome":
        return "gnome"
    return desktop


def get_builder(builder_file_name):
    """Return a fully-instantiated Gtk.Builder instance from specified ui file

    :param builder_file_name: The name of the builder file, without extension.
        Assumed to be in the 'ui' directory under the data path.
    """
    # Look for the ui file that describes the user interface.
    ui_filename = get_data_file('ui', '%s.ui' % (builder_file_name,))
    if not os.path.exists(ui_filename):
        ui_filename = None

    builder = Builder()
    builder.set_translation_domain('catfish')
    builder.add_from_file(ui_filename)
    return builder


class NullHandler(logging.Handler):

    """NullHander class."""

    def emit(self, record):
        """Prohibit emission of signals."""
        pass


def set_up_logging(opts):
    """Set up the logging formatter."""
    # add a handler to prevent basicConfig
    root = logging.getLogger()
    null_handler = NullHandler()
    root.addHandler(null_handler)

    formatter = logging.Formatter("%(levelname)s:%(name)s: "
                                  "%(funcName)s() '%(message)s'")

    logger = logging.getLogger('catfish')
    logger_sh = logging.StreamHandler()
    logger_sh.setFormatter(formatter)
    logger.addHandler(logger_sh)

    search_logger = logging.getLogger('catfish_search')
    search_logger_sh = logging.StreamHandler()
    search_logger_sh.setFormatter(formatter)
    search_logger.addHandler(search_logger_sh)

    lib_logger = logging.getLogger('catfish_lib')
    lib_logger_sh = logging.StreamHandler()
    lib_logger_sh.setFormatter(formatter)
    lib_logger.addHandler(lib_logger_sh)

    # Set the logging level to show debug messages.
    if opts.verbose:
        logger.setLevel(logging.DEBUG)
        logger.debug('logging enabled')
        search_logger.setLevel(logging.DEBUG)
        if opts.verbose > 1:
            lib_logger.setLevel(logging.DEBUG)


def get_help_uri(page=None):
    """Return the URI for the documentation."""
    # help_uri from source tree - default language
    here = os.path.dirname(__file__)
    help_uri = os.path.abspath(os.path.join(here, '..', 'help', 'C'))

    if not os.path.exists(help_uri):
        # installed so use gnome help tree - user's language
        help_uri = 'catfish'

    # unspecified page is the index.page
    if page is not None:
        help_uri = '%s#%s' % (help_uri, page)

    return help_uri


def show_uri(parent, link):
    """Open the specified URI."""
    screen = parent.get_screen()
    Gtk.show_uri(screen, link, Gtk.get_current_event_time())


def alias(alternative_function_name):
    '''see http://www.drdobbs.com/web-development/184406073#l9'''
    def decorator(function):
        '''attach alternative_function_name(s) to function'''
        if not hasattr(function, 'aliases'):
            function.aliases = []
        function.aliases.append(alternative_function_name)
        return function
    return decorator



#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#   Catfish - a versatile file searching tool
#   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
#
#   This program is free software: you can redistribute it and/or modify it
#   under the terms of the GNU General Public License version 2, as published
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranties of
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0114
# pylint: disable=C0116
# pylint: disable=C0413

import logging

import gi
gi.require_version('Gtk', '3.0')  # noqa
from gi.repository import Gtk

from catfish_lib.PrefsDialog import PrefsDialog

LOGGER = logging.getLogger('catfish')


# See catfish_lib.PrefsDialog.py for more details about how this class works.
class CatfishPrefsDialog(PrefsDialog):

    """Creates the about dialog for catfish"""
    __gtype_name__ = "CatfishPrefsDialog"

    def finish_initializing(self, builder):
        """Set up the about dialog"""
        super(CatfishPrefsDialog, self).finish_initializing(builder)
        self.changed_properties = []
        self.process_events = False

    def connect_settings(self, settings):
        self.settings = settings
        if self.settings.get_setting("use-headerbar"):
            self.builder.get_object("wl_headerbar").set_active(True)
            self.builder.get_object("wl_headerbar_visible").set_active(True)
        if self.settings.get_setting("show-hidden-files"):
            self.builder.get_object("do_show_hidden").set_active(True)
        if self.settings.get_setting("show-sidebar"):
            self.builder.get_object("do_show_sidebar").set_active(True)
        if self.settings.get_setting("close-after-select"):
            self.builder.get_object("close_after_select").set_active(True)
        if self.settings.get_setting("search-compressed-files"):
            self.builder.get_object(
                "search_in_compressed_files").set_active(True)
        if self.settings.get_setting("file-size-binary"):
            self.builder.get_object("do_show_size_binary").set_active(True)
        self.set_exclude_directories(
            self.settings.get_setting("exclude-paths"))
        self.process_events = True

    def on_wl_titlebar_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("use-headerbar", False)
            self.builder.get_object("wl_titlebar_visible").set_active(True)
        else:
            self.settings.set_setting("use-headerbar", True)
            self.builder.get_object("wl_headerbar_visible").set_active(True)
        self.builder.get_object("wl_info").show()
        self.changed_properties.append("use-headerbar")

    def on_do_show_hidden_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("show-hidden-files", True)
        else:
            self.settings.set_setting("show-hidden-files", False)
        self.changed_properties.append("show-hidden-files")

    def on_do_show_sidebar_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("show-sidebar", True)
        else:
            self.settings.set_setting("show-sidebar", False)
        self.changed_properties.append("show-sidebar")

    def on_do_show_size_binary_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("file-size-binary", True)
        else:
            self.settings.set_setting("file-size-binary", False)
        self.changed_properties.append("file-size-binary")

    def on_close_after_select_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("close-after-select", True)
        else:
            self.settings.set_setting("close-after-select", False)
        self.changed_properties.append("close-after-select")

    def on_search_in_compressed_files_toggled(self, widget):
        if not self.process_events:
            return
        if widget.get_active():
            self.settings.set_setting("search-compressed-files", True)
        else:
            self.settings.set_setting("search-compressed-files", False)
        self.changed_properties.append("search-compressed-files")

    def on_add_directory_clicked(self, widget):  # pylint: disable=W0613
        dlg = Gtk.FileChooserDialog("Add Excluded Directory",
                                    self,
                                    Gtk.FileChooserAction.SELECT_FOLDER,
                                    (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                     Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
        response = dlg.run()
        if response == Gtk.ResponseType.OK:
            path = dlg.get_filename()
            treeview = self.builder.get_object("exclude_treeview")
            model = treeview.get_model()
            model.append([path])
            self.treemodel_to_settings(model)
        dlg.destroy()

    def on_remove_directory_clicked(self, widget):  # pylint: disable=W0613
        treeview = self.builder.get_object("exclude_treeview")
        model = treeview.get_model()
        sel = treeview.get_selection().get_selected()
        if sel is not None:
            model.remove(sel[1])
        self.treemodel_to_settings(model)

    def treemodel_to_settings(self, model):
        child = model.iter_children()

        rows = []
        while child is not None:
            path = model[child][0]
            if path not in rows and len(path) > 0:
                rows.append(path)
            child = model.iter_next(child)

        rows.sort()

        self.settings.set_setting("exclude-paths", rows)

    def set_exclude_directories(self, exclude_directories):
        treeview = self.builder.get_object("exclude_treeview")
        model = treeview.get_model()

        for path in exclude_directories:
            model.append([path])



#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#   Catfish - a versatile file searching tool
#   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
#
#   This program is free software: you can redistribute it and/or modify it
#   under the terms of the GNU General Public License version 2, as published
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranties of
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0413

import optparse
import signal
import sys

from locale import gettext as _

import gi
gi.require_version('Gtk', '3.0')  # noqa

from gi.repository import Gtk

from catfish import CatfishWindow

from catfish_lib import set_up_logging, get_version


def parse_options():
    """Support for command line options"""
    usage = _("Usage: %prog [options] path query")
    parser = optparse.OptionParser(version="catfish %s" % get_version(),
                                   usage=usage)
    parser.add_option(
        "-v", "--verbose", action="count", dest="verbose",
        help=_("Show debug messages (-vv will also debug catfish_lib)"))

    parser.add_option('', '--large-icons', action='store_true',
                      dest='icons_large', help=_('Use large icons'))
    parser.add_option('', '--thumbnails', action='store_true',
                      dest='thumbnails', help=_('Use thumbnails'))
    parser.add_option('', '--iso-time', action='store_true',
                      dest='time_iso', help=_('Display time in ISO format'))
    # Translators: Do not translate PATH, it is a variable.
    parser.add_option('', '--path', help=_("Set the default search path"))
    parser.add_option('', '--exact', action='store_true',
                      help=_('Perform exact match'))
    parser.add_option('', '--hidden', action='store_true',
                      help=_('Include hidden files'))
    parser.add_option('', '--fulltext', action='store_true',
                      help=_('Perform fulltext search'))
    parser.add_option('', '--start', action='store_true',
                      help=_("If path and query are provided, start searching "
                             "when the application is displayed."))
    parser.add_option('', '--sort', help=_("set a default column to sort by "
                                           "(name|size|path|date|type),(asc|desc)"))
    parser.add_option('', '--close-after-select', action='store_true',dest='close_after_select',
                      help=_('Close after selecting a file'))
    parser.add_option('', '--persist-after-select', action='store_true',dest='persist_after_select',
                      help=_('Do not close after selecting a file'))
    parser.set_defaults(icons_large=0, thumbnails=0, time_iso=0,
                        path=None, start=False, sort=None,
                        exact=0, hidden=0, fulltext=0, file_action='open')

    (options, args) = parser.parse_args()

    set_up_logging(options)
    return (options, args)


def main():
    'constructor for your class instances'
    options, args = parse_options()

    # Run the application.
    window = CatfishWindow.CatfishWindow()
    window.parse_options(options, args)
    if(window.options.persist_after_select and window.options.close_after_select):
        print("Error: Conflicting options \"--close-after-select\" and \"--persist-after-select\"")
        return
    window.show()

    # Allow application shutdown with Ctrl-C in terminal
    signal.signal(signal.SIGINT, signal.SIG_DFL)
    Gtk.main()



#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#   Catfish - a versatile file searching tool
#   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
#
#   This program is free software: you can redistribute it and/or modify it
#   under the terms of the GNU General Public License version 2, as published
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranties of
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program.  If not, see <https://www.gnu.org/licenses/>.

import os
from locale import gettext as _

import pexpect

from gi.repository import Gtk, GdkPixbuf


# Check if the LANG variable needs to be set
use_env = False


def check_dependencies(commands=[]):
    """Check for the existence of required commands, and sudo access"""
    # Check for required commands
    for command in commands:
        if pexpect.which(command) is None:
            return False

    # Check for sudo or pkexec
    if pexpect.which("pkexec") is not None:
        return True

    if pexpect.which("sudo") is None:
        return False

    # Check for LANG requirements
    child = env_spawn('sudo -v', 1)
    if child.expect([".*ssword.*", "Sorry",
                     pexpect.EOF,
                     pexpect.TIMEOUT]) == 3:
        global use_env
        use_env = True
    child.close()

    # Check for sudo rights
    child = env_spawn('sudo -v', 1)
    try:
        index = child.expect([".*ssword.*", "Sorry",
                              pexpect.EOF, pexpect.TIMEOUT])
        child.close()
        if index in [0, 2]:
            # User in sudoers, or already admin
            return True

    except Exception:
        # Something else went wrong.
        child.close()

    return False


def env_spawn(command, timeout):
    """Use pexpect.spawn, adapt for timeout and env requirements."""
    if use_env:
        child = pexpect.spawn(command, env={"LANG": "C"})
    else:
        child = pexpect.spawn(command)
    child.timeout = timeout
    return child


def passwordless_sudo():
    """Return true if no password required to use sudo."""
    p = env_spawn("sudo -n true", 2)
    p.expect(pexpect.EOF)
    p.close()
    return p.exitstatus == 0


def prefer_pkexec():
    return prefer_pkexec


class SudoDialog(Gtk.Dialog):

    '''
    Creates a new SudoDialog. This is a replacement for using gksudo which
    provides additional flexibility when performing sudo commands.

    Only used to verify password by issuing 'sudo /bin/true'.

    Keyword arguments:
    - parent:   Optional parent Gtk.Window
    - icon:     Optional icon name or path to image file.
    - message:  Optional message to be displayed instead of the defaults.
    - name:     Optional name to be displayed, for when message is not used.
    - retries:  Optional maximum number of password attempts. -1 is unlimited.

    Signals emitted by run():
    - NONE:     Dialog closed.
    - CANCEL:   Dialog cancelled.
    - REJECT:   Password invalid.
    - ACCEPT:   Password valid.
    '''

    def __init__(self, title=None, parent=None, icon=None, message=None,
                 name=None, retries=-1):
        """Initialize the SudoDialog."""
        # initialize the dialog
        super().__init__(title=title,
                         transient_for=parent,
                         modal=True,
                         destroy_with_parent=True)
        #
        self.connect("show", self.on_show)
        if title is None:
            title = _("Password Required")
        self.set_title(title)

        self.set_border_width(5)

        # Content Area
        content_area = self.get_content_area()
        grid = Gtk.Grid.new()
        grid.set_row_spacing(6)
        grid.set_column_spacing(12)
        grid.set_margin_left(5)
        grid.set_margin_right(5)
        content_area.add(grid)

        # Icon
        self.dialog_icon = Gtk.Image.new_from_icon_name("dialog-password",
                                                        Gtk.IconSize.DIALOG)
        grid.attach(self.dialog_icon, 0, 0, 1, 2)

        # Text
        self.primary_text = Gtk.Label.new("")
        self.primary_text.set_use_markup(True)
        self.primary_text.set_halign(Gtk.Align.START)
        self.secondary_text = Gtk.Label.new("")
        self.secondary_text.set_use_markup(True)
        self.secondary_text.set_halign(Gtk.Align.START)
        self.secondary_text.set_margin_top(6)
        grid.attach(self.primary_text, 1, 0, 1, 1)
        grid.attach(self.secondary_text, 1, 1, 1, 1)

        # Infobar
        self.infobar = Gtk.InfoBar.new()
        self.infobar.set_margin_top(12)
        self.infobar.set_message_type(Gtk.MessageType.WARNING)
        content_area = self.infobar.get_content_area()
        infobar_icon = Gtk.Image.new_from_icon_name("dialog-warning",
                                                    Gtk.IconSize.BUTTON)
        label = Gtk.Label.new(_("Incorrect password... try again."))
        content_area.add(infobar_icon)
        content_area.add(label)
        grid.attach(self.infobar, 0, 2, 2, 1)
        content_area.show_all()
        self.infobar.set_no_show_all(True)

        # Password
        label = Gtk.Label.new("")
        label.set_use_markup(True)
        label.set_markup("<b>%s</b>" % _("Password:"))
        label.set_halign(Gtk.Align.START)
        label.set_margin_top(12)
        self.password_entry = Gtk.Entry()
        self.password_entry.set_visibility(False)
        self.password_entry.set_activates_default(True)
        self.password_entry.set_margin_top(12)
        grid.attach(label, 0, 3, 1, 1)
        grid.attach(self.password_entry, 1, 3, 1, 1)

        # Buttons
        button = self.add_button(_("Cancel"), Gtk.ResponseType.CANCEL)
        button_box = button.get_parent()
        button_box.set_margin_top(24)
        ok_button = Gtk.Button.new_with_label(_("OK"))
        ok_button.connect("clicked", self.on_ok_clicked)
        ok_button.set_receives_default(True)
        ok_button.set_can_default(True)
        ok_button.set_sensitive(False)
        self.set_default(ok_button)
        button_box.pack_start(ok_button, True, True, 0)

        self.password_entry.connect("changed", self.on_password_changed,
                                    ok_button)

        self.set_dialog_icon(icon)

        # add primary and secondary text
        if message:
            primary_text = message
            secondary_text = None
        else:
            primary_text = _("Enter your password to\n"
                             "perform administrative tasks.")
            secondary_text = _("The application '%s' lets you\n"
                               "modify essential parts of your system." % name)
        self.format_primary_text(primary_text)
        self.format_secondary_text(secondary_text)

        self.attempted_logins = 0
        self.max_attempted_logins = retries
        self.password_valid = False

    def on_password_changed(self, widget, button):
        """Set the apply button sensitivity based on password input."""
        button.set_sensitive(len(widget.get_text()) > 0)

    def format_primary_text(self, message_format):
        '''
        Format the primary text widget.
        '''
        self.primary_text.set_markup("<big><b>%s</b></big>" % message_format)

    def format_secondary_text(self, message_format):
        '''
        Format the secondary text widget.
        '''
        self.secondary_text.set_markup(message_format)

    def set_dialog_icon(self, icon=None):
        '''
        Set the icon for the dialog. If the icon variable is an absolute
        path, the icon is from an image file. Otherwise, set the icon from an
        icon name.
        '''
        # default icon size is dialog.
        icon_size = Gtk.IconSize.DIALOG
        if icon:
            if os.path.isfile(os.path.abspath(icon)):
                # icon is a filename, so load it into a pixbuf to an image
                pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(icon,
                                                                icon_size,
                                                                icon_size)
                self.dialog_icon.set_from_pixbuf(pixbuf)
                self.set_icon_from_file(icon)
            else:
                # icon is an named icon, so load it directly to an image
                self.dialog_icon.set_from_icon_name(icon, icon_size)
                self.set_icon_name(icon)
        else:
            # fallback on password icon
            self.dialog_icon.set_from_icon_name('dialog-password', icon_size)
            self.set_icon_name('dialog-password')

    def on_show(self, widget):  # pylint: disable=W0613
        '''When the dialog is displayed, clear the password.'''
        self.set_password('')
        self.password_valid = False

    def on_ok_clicked(self, widget):  # pylint: disable=W0613
        '''
        When the OK button is clicked, attempt to use sudo with the currently
        entered password.  If successful, emit the response signal with ACCEPT.

        If unsuccessful, try again until reaching maximum attempted logins,
        then emit the response signal with REJECT.
        '''
        if self.attempt_login():
            self.password_valid = True
            self.emit("response", Gtk.ResponseType.ACCEPT)
        else:
            self.password_valid = False
            # Adjust the dialog for attactiveness.
            self.infobar.show()
            self.password_entry.grab_focus()
            if self.attempted_logins == self.max_attempted_logins:
                self.attempted_logins = 0
                self.emit("response", Gtk.ResponseType.REJECT)

    def get_password(self):
        '''Return the currently entered password, or None if blank.'''
        if not self.password_valid:
            return None
        password = self.password_entry.get_text()
        if password == '':
            return None
        return password

    def set_password(self, text=None):
        '''Set the password entry to the defined text.'''
        if text is None:
            text = ''
        self.password_entry.set_text(text)
        self.password_valid = False

    def attempt_login(self):
        '''
        Try to use sudo with the current entered password.

        Return True if successful.
        '''
        # Set the pexpect variables and spawn the process.
        child = env_spawn('sudo /bin/true', 1)
        try:
            # Check for password prompt or program exit.
            child.expect([".*ssword.*", pexpect.EOF])
            child.sendline(self.password_entry.get_text())
            child.expect(pexpect.EOF)
        except pexpect.TIMEOUT:
            # If we timeout, that means the password was unsuccessful.
            pass
        # Close the child process if it is still open.
        child.close()
        # Exit status 0 means success, anything else is an error.
        if child.exitstatus == 0:
            self.attempted_logins = 0
            return True
        self.attempted_logins += 1
        return False



#!/usr/bin/env python
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#   Catfish - a versatile file searching tool
#   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
#   Copyright (C) 2012-2022 Sean Davis <bluesabre@xfce.org>
#
#   This program is free software: you can redistribute it and/or modify it
#   under the terms of the GNU General Public License version 2, as published
#   by the Free Software Foundation.
#
#   This program is distributed in the hope that it will be useful, but
#   WITHOUT ANY WARRANTY; without even the implied warranties of
#   MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License along
#   with this program.  If not, see <https://www.gnu.org/licenses/>.

'''facade - makes catfish_lib package easy to refactor

while keeping its api constant'''
from . helpers import set_up_logging  # noqa
from . Window import Window  # noqa
from . catfishconfig import get_version, get_about  # noqa
